## 1.3.0.10 (2023-03-29)

Add default values to `pika.spec` (#9973)

## 1.3.0.9 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 1.3.0.8 (2023-03-25)

Use of twisted in pika (#9494)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.3.0.7 (2023-02-28)

Enable running stubtest on more of `types-pika` (#9826)

Make aliases for non-imported dependency private

## 1.3.0.6 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 1.3.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.3.0.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 1.3.0.3 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 1.3.0.2 (2022-12-19)

Annotate more items in pika.channel (#9385)

## 1.3.0.1 (2022-12-14)

pika: Make Method generic, annotate DeclareOk (#9360)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.3.0.0 (2022-12-14)

Distribute our pika stubs under an alternate name (#9358)

Cf. #9246

## 1.3.0.0 (2022-11-23)

Disable pika uploads for now (#9257)

See #9246.

Further annotate pika (#9240)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

Initial pika stubs (#9200)

